function N = dsvneutraldens2v2(species,r,sza,aza)

% DSVNEUTRALDENS2V2('species',r,sza,aza)
%      gives the density at distance r from the centre of Venus for 
%      the neutral species 'species'
%      sza is the solar zenith angle and aza is the azimuthal angle,
%      that is the angle between the positive y-axis and the projection 
%      of the r-vector on to the yz-plane
%      H_the, H_hot, O_the, O_hot and He are the only neutral species allowed. 
%
%      The density is given in m^{-3}
%      
%      HG 2002-12-03
%      This is simply a new version of vneutraldens that takes vector 
%      inputs for r, sza, and aza.  HG 2003-09-04
%
%      New version with the same densities as those used by Kallio,
%      Jrvinen and Janhunen, Planetary and Space Science, 2006.
%      HG 2006-05-15
  
if nargin<3, error('Can I have some more input arguments, please.'); end
if min(sza)<0 | max(sza)>pi, 
    error(['When a true genius appears in the world, you may know him by ' ...
	   'this sign, that the dunces are all in confederacy against him.'])
end
aza=mod(aza,2*pi);

rv=6051.8e3;

switch species 
  case 'H_the'
    
    r0=rv+170e3; hsnoon = 1.382e8; n0noon = 1.32e11;
    hsmidn=3.58e8;n0midn=2.93e12;
    N=n0noon.*exp(hsnoon.*(1./r-1./r0)).*(pi-sza)/pi + ...
      n0midn.*exp(hsmidn.*(1./r-1./r0)).*sza/pi;
    
 case 'H_hot'
  zi=sza<pi/2;                % True on the dayside
  Nzi=(1-2*sza/pi).*exp([-6.2625e-05 15.4817 3.6414e+04]* ...
                        (ones(3,1)*(r*1e-3)).^([1;0;-1]*ones(size(r))) ) + ...
      (2*sza/pi).*exp([-8.4607e-05 15.9944 2.9743e+04]* ...
                      (ones(3,1)*(r*1e-3)).^([1;0;-1]*ones(size(r))) );
  Nzinot=(2-2*sza/pi).*exp([-8.4607e-05 15.9944 2.9743e+04]* ...
                       (ones(3,1)*(r*1e-3)).^([1;0;-1]*ones(size(r))) ) + ...
         (2*sza/pi-1).*exp([-6.2309e-05 15.2723 4.3781e+04]* ...
                           (ones(3,1)*(r*1e-3)).^([1;0;-1]*ones(size(r))) );
  N=Nzi.*zi + Nzinot.*(~zi);
  
 case 'O_hot'
  r0noon=rv+200e3; hsnoon = 9.845e7; n0noon = 7.5e10;
  r0midn=rv+300e3; hsmidn = 1.3e8; n0midn = 2e9;
  N=n0noon.*exp(hsnoon.*(1./r-1./r0noon)).* ...
    zetapart2(hsnoon,r0noon,hsnoon./r).*(pi-sza)/pi + ...
    n0midn.*exp(hsmidn.*(1./r-1./r0midn)).* ...
    zetapart2(hsmidn,r0midn,hsmidn./r).*sza/pi;
  
 otherwise
  error('Illegal species!')
end     % end switch species
